@@ -2,12 +2,13 @@ package Datahub::Factory::Env;
 
 use Datahub::Factory::Sane;
 
+our $VERSION = '1.70';
+
 use Datahub::Factory::Util qw(require_package);
 use Moo;
 use Catmandu;
-use namespace::clean;
 use Config::Simple;
-use Data::Dumper qw(Dumper);
+use namespace::clean;
 
 with 'Datahub::Factory::Logger';
 
@@ -31,7 +32,7 @@ sub fixer {
     if (!defined($name) || (ref $name eq 'ARRAY' && scalar @{$name} == 0)) {
         die 'Undefined value for plugin at [Fixer]';
     }
-    
+
     return require_package($name, $ns);
 }
 
@@ -43,13 +44,13 @@ sub exporter {
     if (!defined($name) || (ref $name eq 'ARRAY' && scalar @{$name} == 0)) {
         die 'Undefined value for plugin at [Exporter]';
     }
-    
+
     return require_package($name, $ns);
 }
 
 sub pipeline {
     my $self = shift;
-    require_package('PipelineConfig', 'Datahub::Factory')->new({'conf_object' => @_});
+    require_package('Pipeline', 'Datahub::Factory')->new({'file_name' => @_});
 }
 
 sub module {
