@@ -1,10 +1,9 @@
 package Datahub::Factory::Exporter::Datahub;
 
-use strict;
-use warnings;
-
 use Datahub::Factory::Sane;
 
+our $VERSION = '1.70';
+
 use Moo;
 use Catmandu;
 use namespace::clean;
