@@ -1,10 +1,12 @@
 package Datahub::Factory::Importer::OAI;
 
-use strict;
-use warnings;
+use Datahub::Factory::Sane;
+
+our $VERSION = '1.70';
 
-use Catmandu::Importer::OAI;
 use Moo;
+use Catmandu::Importer::OAI;
+use namespace::clean;
 
 with 'Datahub::Factory::Importer';
 
