@@ -1,14 +1,15 @@
 package Datahub::Factory::Importer::TMS;
 
-use strict;
-use warnings;
+use Datahub::Factory::Sane;
+
+our $VERSION = '1.70';
 
 use Moo;
 use Catmandu;
-
 use DBI;
 use Log::Log4perl;
 use Config::Simple;
+use namespace::clean;
 
 use Datahub::Factory::Importer::TMS::Index;
 
@@ -117,4 +118,4 @@ it under the same terms as Perl itself.
 L<Datahub::Factory>
 L<Catmandu>
 
-=cut
\ No newline at end of file
+=cut
