@@ -1,12 +1,13 @@
 package Datahub::Factory::TMS::Importer::Index;
 
-# TODO: to datahub-factory-kmska
+use Datahub::Factory::Sane;
+
+our $VERSION = '1.70';
 
 use Moo;
 use Catmandu;
-use strict;
-
 use DBI;
+use namespace::clean;
 
 has db_host     => (is => 'ro', required => 1);
 has db_name     => (is => 'ro', required => 1);
@@ -90,4 +91,4 @@ sub add_indices {
     }
 }
 
-1;
\ No newline at end of file
+1;
